Struct sc_executor::sandbox::Store [−][src]
pub struct Store<DT> { /* fields omitted */ }Expand description
This struct keeps track of all sandboxed components.
This is generic over a supervisor function reference type.
Implementations
Create a new empty sandbox store.
Create a new memory instance and return it’s index.
Errors
Returns Err if the memory couldn’t be created.
Typically happens if initial is more than maximum.
Returns SandboxInstance by instance_idx.
Errors
Returns Err If instance_idx isn’t a valid index of an instance or
instance is already torndown.
Returns dispatch thunk by instance_idx.
Errors
Returns Err If instance_idx isn’t a valid index of an instance or
instance is already torndown.
Returns reference to a memory instance by memory_idx.
Errors
Returns Err If memory_idx isn’t a valid index of an memory or
if memory has been torn down.
Tear down the memory at the specified index.
Errors
Returns Err if memory_idx isn’t a valid index of an memory or
if it has been torn down.
Tear down the instance at the specified index.
Errors
Returns Err if instance_idx isn’t a valid index of an instance or
if it has been torn down.
pub fn instantiate(
&mut self,
wasm: &[u8],
guest_env: GuestEnvironment,
state: u32,
sandbox_context: &mut dyn SandboxContext
) -> Result<UnregisteredInstance, InstantiationError>
pub fn instantiate(
&mut self,
wasm: &[u8],
guest_env: GuestEnvironment,
state: u32,
sandbox_context: &mut dyn SandboxContext
) -> Result<UnregisteredInstance, InstantiationError>
Instantiate a guest module and return it’s index in the store.
The guest module’s code is specified in wasm. Environment that will be available to
guest module is specified in guest_env. A dispatch thunk is used as function that
handle calls from guests. state is an opaque pointer to caller’s arbitrary context
normally created by sp_sandbox::Instance primitive.
Note: Due to borrowing constraints dispatch thunk is now propagated using DTH
Returns uninitialized sandboxed module instance or an instantiation error.