[−][src]Struct sc_executor::sandbox::SupervisorFuncIndex
Index of a function inside the supervisor.
This is a typically an index in the default table of the supervisor, however the exact meaning of this index is depends on the implementation of dispatch function.