NativeElseWasmExecutor

Struct NativeElseWasmExecutor 

pub struct NativeElseWasmExecutor<D: NativeExecutionDispatch> { /* private fields */ }
👎Deprecated:

Native execution will be deprecated, please replace with WasmExecutor. Will be removed at end of 2024.

A generic CodeExecutor implementation that uses a delegate to determine wasm code equivalence and dispatch to native code when possible, falling back on WasmExecutor when not.

Implementations

Source

impl<D: NativeExecutionDispatch> NativeElseWasmExecutor<D>

pub fn new( fallback_method: WasmExecutionMethod, default_heap_pages: Option<u64>, max_runtime_instances: usize, runtime_cache_size: u8, ) -> Self

👎Deprecated:

use Self::new_with_wasm_executor method instead of it

Create new instance.

Parameters

fallback_method - Method used to execute fallback Wasm code.

default_heap_pages - Number of 64KB pages to allocate for Wasm execution. Internally this will be mapped as HeapAllocStrategy::Static where default_heap_pages represent the static number of heap pages to allocate. Defaults to DEFAULT_HEAP_ALLOC_STRATEGY if None is provided.

max_runtime_instances - The number of runtime instances to keep in memory ready for reuse.

runtime_cache_size - The capacity of runtime cache.

pub fn new_with_wasm_executor( executor: WasmExecutor<ExtendedHostFunctions<SubstrateHostFunctions, D::ExtendHostFunctions>>, ) -> Self

Create a new instance using the given WasmExecutor.

pub fn disable_use_native(&mut self)

Disable to use native runtime when possible just behave like WasmExecutor.

Default to enabled.

pub fn allow_missing_host_functions( &mut self, allow_missing_host_functions: bool, )

👎Deprecated:

use Self::new_with_wasm_executor method instead of it

Ignore missing function imports if set true.