[−][src]Crate sc_executor
A crate that provides means of executing/dispatching calls into the runtime.
There are a few responsibilities of this crate at the moment:
- It provides an implementation of a common entrypoint for calling into the runtime, both wasm and compiled.
- It defines the environment for the wasm execution, namely the host functions that are to be provided into the wasm runtime module.
- It also provides the required infrastructure for executing the current wasm runtime (specified
by the current value of
:codein the provided externalities), i.e. interfacing with wasm engine used, instance cache.
Re-exports
pub use wasmi; |
Modules
| deprecated_host_interface | Definition and implementation of the old and deprecated Substrate runtime interface for the host. |
| error | Rust executor possible errors. |
| sandbox | This module implements sandboxing support in the runtime. |
Macros
| convert_args | Converts arguments into respective WASM types. |
| gen_signature | Generates a WASM signature for given list of parameters. |
| impl_wasm_host_interface | Implements the wasm host interface for the given type. |
| marshall | Pass the list of parameters by converting them to respective WASM types. |
| native_executor_instance | Implements a |
| unmarshall_args | Converts the list of arguments coming from WASM into their native types. |
Structs
| NativeExecutor | A generic |
| NativeVersion | |
| RuntimeVersion | Runtime version.
This should not be thought of as classic Semver (major/minor/tiny).
This triplet have different semantics and mis-interpretation could cause problems.
In particular: bug fixes should result in an increment of |
Enums
| WasmExecutionMethod | Specification of different methods of executing the runtime Wasm code. |
Traits
| Codec | Trait that allows zero-copy read/write of value-references to/from slices in LE format. |
| NativeExecutionDispatch | Delegate for dispatching a CodeExecutor call. |
| RuntimeInfo | Provides runtime information. |
Functions
| call_in_wasm | Call the given |
| call_in_wasm_with_host_functions | Non-generic version of |
| with_externalities_safe | Set up the externalities and safe calling environment to execute runtime calls. |